@@ -26,4 +26,9 @@ FROM
         RIGHT JOIN primary_table as pt ON jt.primary_table_id = pt.id
 WHERE
         jt.id = ?
-        AND pt.user_id = ?;
\ No newline at end of file
+        AND pt.user_id = ?;
+
+-- name: DeleteJoinWithSubquery :exec
+DELETE pt
+FROM primary_table pt
+JOIN (SELECT 1 as id) jt ON pt.id = jt.id;
