@@ -1,7 +1,8 @@
 CREATE TABLE foo (
     other     text NOT NULL,
     tagged    text NOT NULL,
-    tag3      text NOT NULL
+    tag3      text NOT NULL,
+    nulltext text
 );
 
 CREATE TABLE bar (
