@@ -43,5 +43,10 @@ func Singular(s SingularParams) string {
 	if strings.ToLower(s.Name) == "waves" {
 		return "wave"
 	}
+
+	if strings.ToLower(s.Name) == "metadata" {
+		return "metadata"
+	}
+
 	return upstream.Singular(s.Name)
 }
